@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 # shortcuts
 #  os and distros
@@ -67,6 +67,8 @@ sub mapping {
        [package => ['libhdf4-dev', 'yasm']]],
       [like_fedora,
        [package => 'hdf-devel']],
+      [os_darwin,
+       [package => 'hdf4']], # but does not work, module expects static libdf.a which is not provided
      ],
 
      [cpanmod => 'Alien::IUP',
@@ -227,7 +229,10 @@ sub mapping {
       [os_freebsd,
        [package => 'flac']],
       [like_debian,
-       [package => 'libflac-dev']]],
+       [package => 'libflac-dev']],
+      [like_fedora,
+       [package => 'flac-devel']],
+     ],
 
      [cpanmod => 'Audio::GSM',
       [os_freebsd,
@@ -383,6 +388,8 @@ sub mapping {
        [package => 'libcdb-dev']],
       [like_fedora,
        [package => 'tinycdb-devel']],
+      [os_darwin,
+       [package => 'tinycdb']], # but test failures
      ],
 
      [cpanmod => 'CDB_File::Generator',
@@ -430,6 +437,8 @@ sub mapping {
        [package => 'liblzo2-dev']],
       [like_fedora,
        [package => 'lzo-devel']],
+      [os_darwin,
+       [package => 'lzo']],
      ],
 
      [cpanmod => 'Config::Augeas',
@@ -623,6 +632,8 @@ sub mapping {
        [package => 'unixodbc-dev']],
       [like_fedora,
        [package => 'libiodbc-devel']], # but building does not work out of the box, Makefile.PL needs patching
+      [os_darwin,
+       [package => 'unixodbc']],
      ],
 
      [cpanmod => 'DBD::Pg',
@@ -759,6 +770,7 @@ sub mapping {
        [package => 'libattr1-dev']],
       [like_fedora,
        [package => 'libattr-devel']],
+      # no special packages needed on freebsd and macosx
      ],
 
      [cpanmod => 'File::LibMagic',
@@ -780,7 +792,10 @@ sub mapping {
       [os_freebsd,
        [package => 'librsync']],
       [like_debian,
-       [package => 'librsync-dev']]],
+       [package => 'librsync-dev']],
+      [like_fedora,
+       [package => 'librsync-devel']], # but compilation failures on CentOS7
+     ],
 
      [cpanmod => 'Filesys::SmbClient',
       ## XXX unclear which package is the correct one
@@ -1109,7 +1124,10 @@ sub mapping {
       [os_freebsd,
        [package => 'libgtop']],
       [like_debian,
-       [package => 'libgtop2-dev']]],
+       [package => 'libgtop2-dev']],
+      [os_darwin,
+       [package => 'libgtop']],
+     ],
 
      [cpanmod => 'Heimdal::Kadm5',
       [os_freebsd,
@@ -1140,7 +1158,9 @@ sub mapping {
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => []], # not available before jessie
        ],
-       [package => 'libctpp2-dev']]],
+       [package => 'libctpp2-dev']],
+      # ctpp2 not available for homebrew
+     ],
 
      [cpanmod => 'HTML::Tidy',
       [os_freebsd,
@@ -1298,7 +1318,9 @@ sub mapping {
       [os_freebsd,
        [package => 'python']],
       [like_debian,
-       [package => 'python2.7-dev']]],
+       [package => 'python2.7-dev']],
+      # macosx already comes with python, it seems
+     ],
 
      [cpanmod => 'Inline::Ruby',
       [os_freebsd,
@@ -1619,6 +1641,15 @@ sub mapping {
       [like_debian,
        [package => 'libdbus-glib-1-dev']]],
 
+     [cpanmod => 'Net::ESMTP',
+      [os_freebsd,
+       [package => 'libesmtp']],
+      [like_debian,
+       [package => 'libesmtp-dev']],
+      [like_fedora,
+       [package => 'libesmtp-devel']],
+     ],
+
      [cpanmod => 'Net::Jabber::Loudmouth',
       [os_freebsd,
        [package => 'loudmouth']],
@@ -1700,6 +1731,12 @@ sub mapping {
        [package => 'librabbitmq-devel']],
      ],
 
+     ## conflicts with avahi-app on FreeBSD
+     #[cpanmod => "Net::Rendezvous::Publish::Backend::Howl",
+     # [os_freebsd,
+     #  [package => 'howl']],
+     #],
+
      [cpanmod => 'Net::SIGTRAN::SCTP',
       # XXX what about freebsd?
       [like_debian,
@@ -1844,6 +1881,14 @@ sub mapping {
      [cpanmod => 'Pod::Weaver::Plugin::Ditaa',
       [package => 'ditaa']],
 
+     [cpanmod => 'POE::Component::NomadJukebox',
+      # but compilation errors on FreeBSD, Debian and Ubuntu
+      [os_freebsd,
+       [package => 'libnjb']],
+      [like_debian,
+       [package => 'libnjb-dev']],
+     ],
+
      [cpanmod => 'Poppler',
       [os_freebsd,
        [package => ['poppler', 'poppler-glib']]],
@@ -1913,7 +1958,10 @@ sub mapping {
       [os_freebsd,
        [package => 'xapian-core']],
       [like_debian,
-       [package => 'libxapian-dev']]],
+       [package => 'libxapian-dev']],
+      [os_darwin,
+       [package => 'xapian']],
+     ],
 
      [cpanmod => 'SGML::Parser::OpenSP',
       # XXX what about freebsd?
@@ -2198,9 +2246,14 @@ sub mapping {
      [cpanmod => 'WWW::Mechanize::PhantomJS',
       [os_freebsd,
        [package => 'phantomjs']],
-      # for debian no package available, but see https://gist.github.com/julionc/7476620
+      [like_debian,
+       [linuxdistrocodename => [qw(squeeze wheezy jessie precise)],
+	[package => []]], # see also https://gist.github.com/julionc/7476620
+       [package => 'phantomjs']],
       [os_windows,
        [package => 'phantomjs']],
+      [os_darwin,
+       [package => 'phantomjs']],
      ],
 
      [cpanmod => 'Wx',
